This project provides an
[Asciidoctor.js](https://asciidoctor.org/docs/asciidoctor.js) extension
for highlighting source listing blocks using
[highlight.js](https://highlightjs.org) right during document conversion
(instead of in browser on client-side as the built-in highlight.js
support).

It supports all Asciidoctor features such as
[callouts](http://asciidoctor.org/docs/user-manual/#callouts),
[passthroughs](http://asciidoctor.org/docs/user-manual/#passthroughs)
inside a code and all other substitutions, except highlighting of
specified lines (attribute `highlight`).

## Requirements

  - [Node.js](https://nodejs.org/) \>=8.10

  - [@asciidoctor/core](https://www.npmjs.com/package/@asciidoctor/core)
    \>=2.0.0 \<2.3.0

  - [highlight.js](https://www.npmjs.com/package/highlight.js) ^10.4.1

## Installation

Install asciidoctor-highlight.js from npmjs.com:

``` sh
npm install --save asciidoctor-highlight.js
```

## Usage

Assign `highlightjs-ext` to the `source-highlighter` attribute in your
document’s header or via Asciidoctor.js parameters.

### Node.js

**Using global extensions registry.**

``` js
// Load asciidoctor.js and asciidoctor-highlight.js.
const asciidoctor = require('@asciidoctor/core')()
const highlightJsExt = require('asciidoctor-highlight.js')

// Register the extension into global registry.
highlightJsExt.register(asciidoctor.Extensions)

// Convert the content to HTML.
const content = `
[source, js]
console.log('Hello, world!')
`
const html = asciidoctor.convert(content, {
  attributes: { 'source-highlighter': 'highlightjs-ext' },
})
console.log(html)
```

**Using custom extensions registry.**

``` js
// Load asciidoctor.js and asciidoctor-highlight.js.
const asciidoctor = require('@asciidoctor/core')()
const highlightJsExt = require('asciidoctor-highlight.js')

// Register the extension into custom registry.
const registry = asciidoctor.Extensions.create()
highlightJsExt.register(registry)

// Convert the content to HTML.
const content = `
[source, js]
console.log('Hello, world!')
`
const html = asciidoctor.convert(content, {
  'extension_registry': registry,
  attributes: { 'source-highlighter': 'highlightjs-ext' },
})
console.log(html)
```

### Attributes

You can further customize the source block output with additional
highlight.js attributes:

  - highlightjs-default-lang  
    Controls the default source code language for fallback when the
    language is not specified in a source block or with attribute
    `source-language`. It can be any language name or alias supported by
    highlight.js, `none` to skip highlighting, or `auto` to use
    highlight.js’s auto-detection. The default is `none`.

## License

This project is licensed under [MIT
License](http://opensource.org/licenses/MIT/). For the full text of the
license, see the [LICENSE](LICENSE) file.
